A collection of functions to compute aggregated scores for each category.
equally_weighted()computes the aggregated category score by taking the mean of assignment scoresweighted_by_points()computes the aggregated category score by taking the weighted mean of assignment scores using aweightsvectormax_score()computes the aggregated category score by taking the maximum of assignment scoresmin_score()computes the aggregated category score by taking the minimum of assignment scoresnone()is used if there is only one assignment in a category and returns that single score; otherwise it defaults toequally_weighted
Usage
equally_weighted(grades_mat, category, assignments, weights = c())
weighted_by_points(grades_mat, category, assignments, weights = c())
max_score(grades_mat, category, assignments, weights = c())
min_score(grades_mat, category, assignments, weights = c())
weighted_mean(grades_mat, category, assignments, weights)
none(grades_mat, category, assignments, weights = c())