This function calculates the grade of a single category based on the policy file.
Note that this function is called within calculate_grades() and it should not be
used on its own.
This function calculates the grade of a single category based on the policy file.
Note that this function is called within calculate_grades() and it should not be
used on its own.