A collection of functions to apply lateness policies if the lateness of an assignment falls within a specified threshold
until()determines if the lateness forassignmentsis less than or equal tolate_policybetween()determines if lateness forassignmentsis betweenlate_policyafter()determines if lateness forassignmentsis more than or equal tolate_policyadd()addslate_policyto score if the lateness of theassignmentsis within the threshold (Note: a positive value forlate_policywould increase the score for that assignment)scale_by()scales score bylate_policyif the lateness of theassignmentsis within the thresholdset_to()sets score tolate_policyif the lateness of theassignmentsis within the threshold
Usage
until(grades_mat, late_policy, original_late_mat, assignments)
add(grades_mat, late_policy, original_late_mat, assignments)
between(grades_mat, late_policy, original_late_mat, assignments)
scale_by(grades_mat, late_policy, original_late_mat, assignments)
after(grades_mat, late_policy, original_late_mat, assignments)
set_to(grades_mat, late_policy, original_late_mat, assignments)